Imports System.Text

Namespace TD70
	Friend class DatensatzZeileBase
		Private ReadOnly mOwnerObject As String
		Private mZeitreihenName As String
		Private ReadOnly mZeitreihenEinheit As String
		Private ReadOnly mObjectIndex As String
		Private ReadOnly mVarStorManIndex As String
		Private ReadOnly mLinkeAchse As String

		''' <summary>
		''' Dieser Konstruktor erzeugt eine komplett initialisierte Instanz der Klasse.
		''' </summary>
		''' <param name="pOwnerObject">Der Name des Objektes (Lieferant, Speicher...)</param>
		''' <param name="pZeitreihenName">Der Name der Zeitreihe, welche die Zeile referenziert</param>
		''' <param name="pZeitreiheneinheit">Die Einheit der Zeitreihe</param>
		''' <param name="pObjectIndex">Der Schlssel des Objektes</param>
		''' <param name="pVarStorManIndex"></param>
		''' <param name="pLinkeAchse">Kennzeichen, ob die Zeitreihe auf der linken oder rechten Achse dargestellt werden soll</param>
		''' <remarks></remarks>
  Public Sub New(ByRef pOwnerObject As String, ByRef pZeitreihenName As String, ByRef pZeitreiheneinheit As String, ByRef pObjectIndex As String, ByRef pVarStorManIndex As String, ByRef pLinkeAchse As String)

			If (pOwnerObject.Length > OWNER_OBJECT_LENGTH) Then
				Throw New ArgumentException(String.Format("Parameter pOwnerObject darf max. {0} Zeichen lang sein", OWNER_OBJECT_LENGTH))
   End If

			If (pZeitreihenName.Length > ZEITREIHEN_NAME_LENGTH) Then
				Throw New ArgumentException(String.Format("Parameter pZeitreihenName darf max. {0} Zeichen lang sein", ZEITREIHEN_NAME_LENGTH))
   End If

			If (pZeitreiheneinheit.Length > ZEITREIHEN_EINHEIT_LENGTH) Then
				Throw New ArgumentException(String.Format("Parameter pZeitreihenEinheit darf max. {0} Zeichen lang sein", ZEITREIHEN_EINHEIT_LENGTH))
   End If

			If (pObjectIndex.Length > OBJEKT_INDEX_LENGTH) Then
				Throw New ArgumentException(String.Format("Parameter pObjectIndex darf max. {0} Zeichen lang sein", OBJEKT_INDEX_LENGTH))
   End If

			If (pVarStorManIndex.Length > VAR_STORMAN_INDEX_LENGTH) Then
				Throw New ArgumentException(String.Format("Parameter pVarStorManIndex darf max. {0} Zeichen lang sein", VAR_STORMAN_INDEX_LENGTH))
   End If

			If (pLinkeAchse.Length > LINKE_ACHSE_LENGTH) Then
				Throw New ArgumentException(String.Format("Parameter pLinkeAchse darf max. {0} Zeichen lang sein", LINKE_ACHSE_LENGTH))
   End If

			mOwnerObject = pOwnerObject.PadRight(OWNER_OBJECT_LENGTH, " "c)
			mZeitreihenName = pZeitreihenName.PadRight(ZEITREIHEN_NAME_LENGTH, " "c)
			mZeitreihenEinheit = pZeitreiheneinheit.PadRight(ZEITREIHEN_EINHEIT_LENGTH, " "c)
			mObjectIndex = pObjectIndex.PadRight(OBJEKT_INDEX_LENGTH, " "c)
			mVarStorManIndex = pVarStorManIndex.PadRight(VAR_STORMAN_INDEX_LENGTH, " "c)
			mLinkeAchse = pLinkeAchse.PadRight(LINKE_ACHSE_LENGTH, " "c)

  End Sub

		Private Const OWNER_OBJECT_LENGTH As Integer = 50
		Private Const ZEITREIHEN_NAME_LENGTH As Integer = 196
		Private Const ZEITREIHEN_EINHEIT_LENGTH As Integer = 2
		Private Const OBJEKT_INDEX_LENGTH As Integer = 6
		Private Const VAR_STORMAN_INDEX_LENGTH As Integer = 2
		Private Const LINKE_ACHSE_LENGTH As Integer = 2

		''' <summary>
		''' Der Name des Objektes (Lieferant, Speicher...).
		''' </summary>
		''' <value></value>
		''' <returns></returns>
		''' <remarks></remarks>
  Public ReadOnly Property OwnerObject() As String
			Get
				Return mOwnerObject
   End Get
  End Property

		''' <summary>
		''' Der Name der darzustellenden Zeitreihe.
		''' </summary>
		''' <value></value>
		''' <returns></returns>
		''' <remarks></remarks>
  Public ReadOnly Property ZeitreihenName() As String
			Get
				Return mZeitreihenName
   End Get
  End Property

		''' <summary>
		''' Die Einheit der Zeitreihe
		''' </summary>
		''' <value></value>
		''' <returns></returns>
		''' <remarks></remarks>
  Public ReadOnly Property ZeitreihenEinheit() As String
			Get
				Return mZeitreihenEinheit
   End Get
  End Property

		''' <summary>
		''' Der Schlssel des Objektes
		''' </summary>
		''' <value></value>
		''' <returns></returns>
		''' <remarks></remarks>
  Public ReadOnly Property ObjectIndex() As String
			Get
				Return mObjectIndex
   End Get
  End Property

		''' <summary>
		''' TODO: Welche Variable ist dies???
		''' </summary>
		''' <value></value>
		''' <returns></returns>
		''' <remarks></remarks>
  Public ReadOnly Property VarStorManIndex() As String
			Get
				Return mVarStorManIndex
   End Get
  End Property

		''' <summary>
		''' Kennzeichen, ob die Zeitreihe auf der linken oder rechten Achse dargestellt werden soll.
		''' </summary>
		''' <value></value>
		''' <returns></returns>
		''' <remarks></remarks>
  Public ReadOnly Property LinkeAchse() As String
			Get
				Return mLinkeAchse
   End Get
  End Property

		''' <summary>
		''' berschreibt den Namen einer Zeitreihe.
		''' </summary>
		''' <param name="pName"></param>
		''' <remarks></remarks>
  Public Sub SetZeitreihenName(ByVal pName As String)

			If (pName.Length > ZEITREIHEN_NAME_LENGTH) Then
				Throw New ArgumentException(String.Format("Parameter pZeitreihenName darf max. {0} Zeichen lang sein", ZEITREIHEN_NAME_LENGTH))
   End If

			mZeitreihenName = pName.PadRight(ZEITREIHEN_NAME_LENGTH, " "c)

  End Sub

		''' <summary>
		''' Erzeugt eine Instanz der Klasse aus einem String.
		''' </summary>
		''' <param name="pZeile">Die Datensatzzeile aus der Templatedatei</param>
		''' <returns></returns>
		''' <remarks></remarks>
  Public Shared Function FromString(ByRef pZeile As String) As DatensatzZeile

			Dim startpos As Integer = 0
			Dim obj As String = pZeile.Substring(startpos, OWNER_OBJECT_LENGTH)

			startpos += OWNER_OBJECT_LENGTH
			Dim zeitreihe = pZeile.Substring(startpos, ZEITREIHEN_NAME_LENGTH)

			startpos += ZEITREIHEN_NAME_LENGTH
			Dim einheit = pZeile.Substring(startpos, ZEITREIHEN_EINHEIT_LENGTH)

			startpos += ZEITREIHEN_EINHEIT_LENGTH
			Dim idx = pZeile.Substring(startpos, OBJEKT_INDEX_LENGTH)

			startpos += OBJEKT_INDEX_LENGTH
			Dim storManIdx = pZeile.Substring(startpos, VAR_STORMAN_INDEX_LENGTH)

			startpos += VAR_STORMAN_INDEX_LENGTH
			Dim achse = pZeile.Substring(startpos)

			Return New DatensatzZeile(obj, zeitreihe, einheit, idx, storManIdx, achse)

  End Function

		''' <summary>
		''' Erzeugt eine String-Reprsentation derInstanz-Daten.
		''' </summary>
		''' <returns></returns>
		''' <remarks></remarks>
  Public Overrides Function ToString() As String

			Dim result As New StringBuilder()

			result.Append(mOwnerObject) _
				.Append(mZeitreihenName) _
				.Append(mZeitreihenEinheit) _
				.Append(mObjectIndex) _
				.Append(mVarStorManIndex) _
				.Append(mLinkeAchse)

			Return result.ToString()

  End Function
 end class
End NameSpace